@@ -175,7 +175,7 @@ function(obs.error="none", fixed)
     ## this scales diagnostic parameters to the scale of the summaries
     backtransf <- function(mcmc, obs.error) {
         #mcmc <- as.mcmc.list(mcmc)
-        mcmc <- as(mcmc, "mcmc.list")
+        mcmc <- as(mcmc, "MCMClist")
         vn <- varnames(mcmc)
         for (i in seq_len(nchain(mcmc))) {
             if ("lnsigma" %in% vn)
@@ -193,7 +193,7 @@ function(obs.error="none", fixed)
     ## this scales summaries to the scale of diagnostic parameters
     transf <- function(mcmc, obs.error) {
         #mcmc <- as.mcmc.list(mcmc)
-        mcmc <- as(mcmc, "mcmc.list")
+        mcmc <- as(mcmc, "MCMClist")
         vn <- varnames(mcmc)
         for (i in seq_len(nchain(mcmc))) {
             if ("sigma" %in% vn)
